@@ -1,4 +1,4 @@
-/* -*- Mode: C; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
+/* -*- Mode: C; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*
  *  Copyright (C) 2007  Kouhei Sutou <kou@cozmixng.org>
  *
@@ -30,6 +30,9 @@ extern "C" {
     cut_test_context_inspect_string_array(get_current_test_context(),   \
                                           strings)
 
+#define cut_take_string(string)                                         \
+    cut_test_context_take_string(get_current_test_context(), string)
+
 #define cut_test_pass() \
     cut_test_context_pass_assertion(get_current_test_context())
 
@@ -56,5 +59,5 @@ extern "C" {
 #endif /* __CUT_ASSERTIONS_HELPER_H__ */
 
 /*
-vi:ts=4:nowrap:ai:expandtab:sw=4
+vi:nowrap:ai:expandtab:sw=4
 */
