@@ -1,4 +1,4 @@
-/* -*- Mode: C; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
+/* -*- Mode: C; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*
  *  Copyright (C) 2007  Kouhei Sutou <kou@cozmixng.org>
  *
@@ -38,6 +38,7 @@
 #include "cut-test-suite.h"
 #include "cut-ui.h"
 #include "cut-ui-factory.h"
+#include "cut-value-equal.h"
 
 static gboolean initialized = FALSE;
 static gchar *test_directory = NULL;
@@ -106,6 +107,8 @@ cut_init (int *argc, char ***argv)
     if (!g_thread_supported())
         g_thread_init(NULL);
 
+    cut_value_equal_init();
+
     option_context = g_option_context_new("TEST_DIRECTORY");
     g_option_context_add_main_entries(option_context, option_entries, "cutter");
     g_option_context_set_help_enabled(option_context, FALSE);
@@ -235,5 +238,5 @@ cut_run (void)
 }
 
 /*
-vi:ts=4:nowrap:ai:expandtab:sw=4
+vi:nowrap:ai:expandtab:sw=4
 */
