@@ -1,4 +1,4 @@
-/* -*- Mode: C; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
+/* -*- Mode: C; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*
  *  Copyright (C) 2007  Kouhei Sutou <kou@cozmixng.org>
  *
@@ -30,6 +30,7 @@
 #include "cut-runner.h"
 #include "cut-repository.h"
 #include "cut-test-case.h"
+#include "cut-test-result.h"
 
 #include "cut-marshalers.h"
 
@@ -567,12 +568,16 @@ cb_pass_assertion (CutTest *test, CutTestContext *test_context, gpointer data)
 }
 
 static void
-cb_success (CutTest *test, gpointer data)
+cb_success (CutTest *test, CutTestResult *result, gpointer data)
 {
     CutRunner *runner = data;
     CutRunnerPrivate *priv;
 
     priv = CUT_RUNNER_GET_PRIVATE(runner);
+    g_mutex_lock(priv->mutex);
+    priv->results = g_list_prepend(priv->results, g_object_ref(result));
+    g_mutex_unlock(priv->mutex);
+
     g_signal_emit(runner, signals[SUCCESS], 0, test);
 }
 
@@ -963,5 +968,5 @@ cut_runner_run (CutRunner *runner)
 }
 
 /*
-vi:ts=4:nowrap:ai:expandtab:sw=4
+vi:nowrap:ai:expandtab:sw=4
 */
