@@ -1,4 +1,4 @@
-/* -*- Mode: C; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
+/* -*- Mode: C; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*
  *  Copyright (C) 2007  Kouhei Sutou <kou@cozmixng.org>
  *
@@ -25,6 +25,9 @@
 #include <glib-object.h>
 
 #include <cutter/cut-assertions.h>
+#include <cutter/cut-test.h>
+#include <cutter/cut-test-case.h>
+#include <cutter/cut-test-suite.h>
 
 G_BEGIN_DECLS
 
@@ -35,9 +38,6 @@ G_BEGIN_DECLS
 #define CUT_IS_TEST_RESULT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), CUT_TYPE_TEST_RESULT))
 #define CUT_TEST_RESULT_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS((obj), CUT_TYPE_TEST_RESULT, CutTestResultClass))
 
-typedef struct _CutTestResult         CutTestResult;
-typedef struct _CutTestResultClass    CutTestResultClass;
-
 struct _CutTestResult
 {
     GObject object;
@@ -51,9 +51,9 @@ struct _CutTestResultClass
 GType          cut_test_result_get_type   (void) G_GNUC_CONST;
 
 CutTestResult *cut_test_result_new        (CutTestResultStatus status,
-                                           const gchar *test_name,
-                                           const gchar *test_case_name,
-                                           const gchar *test_suite_name,
+                                           CutTest *test,
+                                           CutTestCase *test_case,
+                                           CutTestSuite *test_suite,
                                            const gchar *user_message,
                                            const gchar *system_message,
                                            const gchar *function_name,
@@ -61,6 +61,7 @@ CutTestResult *cut_test_result_new        (CutTestResultStatus status,
                                            guint line);
 
 CutTestResultStatus  cut_test_result_get_status        (CutTestResult *result);
+CutTest             *cut_test_result_get_test          (CutTestResult *result);
 const gchar         *cut_test_result_get_test_name     (CutTestResult *result);
 const gchar         *cut_test_result_get_test_case_name(CutTestResult *result);
 const gchar         *cut_test_result_get_test_suite_name(CutTestResult *result);
@@ -70,11 +71,13 @@ const gchar         *cut_test_result_get_system_message(CutTestResult *result);
 const gchar         *cut_test_result_get_function_name (CutTestResult *result);
 const gchar         *cut_test_result_get_filename      (CutTestResult *result);
 guint                cut_test_result_get_line          (CutTestResult *result);
+gdouble              cut_test_result_get_elapsed       (CutTestResult *result);
+gchar               *cut_test_result_to_xml            (CutTestResult *result);
 
 G_END_DECLS
 
 #endif /* __CUT_TEST_RESULT_H__ */
 
 /*
-vi:ts=4:nowrap:ai:expandtab:sw=4
+vi:nowrap:ai:expandtab:sw=4
 */
