@@ -1,4 +1,4 @@
-/* -*- Mode: C; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
+/* -*- Mode: C; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*
  *  Copyright (C) 2007  Kouhei Sutou <kou@cozmixng.org>
  *
@@ -31,6 +31,7 @@
 #include "cut-test-container.h"
 #include "cut-runner.h"
 #include "cut-marshalers.h"
+#include "cut-test-result.h"
 
 #define CUT_TEST_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE ((obj), CUT_TYPE_TEST, CutTestPrivate))
 
@@ -41,6 +42,7 @@ struct _CutTestPrivate
     gchar *description;
     CutTestFunction test_function;
     GTimer *timer;
+    GHashTable *attributes;
 };
 
 enum
@@ -53,15 +55,15 @@ enum
 
 enum
 {
-    START_SIGNAL,
-    PASS_ASSERTION_SIGNAL,
-    SUCCESS_SIGNAL,
-    FAILURE_SIGNAL,
-    ERROR_SIGNAL,
-    PENDING_SIGNAL,
-    NOTIFICATION_SIGNAL,
-    COMPLETE_SIGNAL,
-    CRASHED_SIGNAL,
+    START,
+    PASS_ASSERTION,
+    SUCCESS,
+    FAILURE,
+    ERROR,
+    PENDING,
+    NOTIFICATION,
+    COMPLETE,
+    CRASHED,
     LAST_SIGNAL
 };
 
@@ -117,7 +119,7 @@ cut_test_class_init (CutTestClass *klass)
                                 G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY);
     g_object_class_install_property(gobject_class, PROP_TEST_FUNCTION, spec);
 
-	cut_test_signals[START_SIGNAL]
+	cut_test_signals[START]
         = g_signal_new ("start",
                 G_TYPE_FROM_CLASS (klass),
                 G_SIGNAL_RUN_LAST,
@@ -126,7 +128,7 @@ cut_test_class_init (CutTestClass *klass)
                 g_cclosure_marshal_VOID__VOID,
                 G_TYPE_NONE, 0);
 
-	cut_test_signals[PASS_ASSERTION_SIGNAL]
+	cut_test_signals[PASS_ASSERTION]
         = g_signal_new ("pass-assertion",
                 G_TYPE_FROM_CLASS (klass),
                 G_SIGNAL_RUN_LAST,
@@ -135,16 +137,16 @@ cut_test_class_init (CutTestClass *klass)
                 g_cclosure_marshal_VOID__OBJECT,
                 G_TYPE_NONE, 1, CUT_TYPE_TEST_CONTEXT);
 
-	cut_test_signals[SUCCESS_SIGNAL]
+	cut_test_signals[SUCCESS]
         = g_signal_new ("success",
                 G_TYPE_FROM_CLASS (klass),
                 G_SIGNAL_RUN_LAST,
                 G_STRUCT_OFFSET (CutTestClass, success),
                 NULL, NULL,
-                g_cclosure_marshal_VOID__VOID,
-                G_TYPE_NONE, 0);
+                g_cclosure_marshal_VOID__OBJECT,
+                G_TYPE_NONE, 1, CUT_TYPE_TEST_RESULT);
 
-	cut_test_signals[FAILURE_SIGNAL]
+	cut_test_signals[FAILURE]
         = g_signal_new ("failure",
                 G_TYPE_FROM_CLASS (klass),
                 G_SIGNAL_RUN_LAST,
@@ -153,7 +155,7 @@ cut_test_class_init (CutTestClass *klass)
                 _cut_marshal_VOID__OBJECT_OBJECT,
                 G_TYPE_NONE, 2, CUT_TYPE_TEST_CONTEXT, CUT_TYPE_TEST_RESULT);
 
-	cut_test_signals[ERROR_SIGNAL]
+	cut_test_signals[ERROR]
         = g_signal_new ("error",
                 G_TYPE_FROM_CLASS (klass),
                 G_SIGNAL_RUN_LAST,
@@ -162,7 +164,7 @@ cut_test_class_init (CutTestClass *klass)
                 _cut_marshal_VOID__OBJECT_OBJECT,
                 G_TYPE_NONE, 2, CUT_TYPE_TEST_CONTEXT, CUT_TYPE_TEST_RESULT);
 
-	cut_test_signals[PENDING_SIGNAL]
+	cut_test_signals[PENDING]
         = g_signal_new ("pending",
                 G_TYPE_FROM_CLASS (klass),
                 G_SIGNAL_RUN_LAST,
@@ -171,7 +173,7 @@ cut_test_class_init (CutTestClass *klass)
                 _cut_marshal_VOID__OBJECT_OBJECT,
                 G_TYPE_NONE, 2, CUT_TYPE_TEST_CONTEXT, CUT_TYPE_TEST_RESULT);
 
-	cut_test_signals[NOTIFICATION_SIGNAL]
+	cut_test_signals[NOTIFICATION]
         = g_signal_new ("notification",
                 G_TYPE_FROM_CLASS (klass),
                 G_SIGNAL_RUN_LAST,
@@ -180,7 +182,7 @@ cut_test_class_init (CutTestClass *klass)
                 _cut_marshal_VOID__OBJECT_OBJECT,
                 G_TYPE_NONE, 2, CUT_TYPE_TEST_CONTEXT, CUT_TYPE_TEST_RESULT);
 
-	cut_test_signals[COMPLETE_SIGNAL]
+	cut_test_signals[COMPLETE]
         = g_signal_new ("complete",
                 G_TYPE_FROM_CLASS (klass),
                 G_SIGNAL_RUN_LAST,
@@ -189,7 +191,7 @@ cut_test_class_init (CutTestClass *klass)
                 g_cclosure_marshal_VOID__VOID,
                 G_TYPE_NONE, 0);
 
-	cut_test_signals[CRASHED_SIGNAL]
+	cut_test_signals[CRASHED]
         = g_signal_new ("crashed",
                 G_TYPE_FROM_CLASS (klass),
                 G_SIGNAL_RUN_LAST,
@@ -208,6 +210,8 @@ cut_test_init (CutTest *test)
 
     priv->test_function = NULL;
     priv->timer = NULL;
+    priv->attributes = g_hash_table_new_full(g_str_hash, g_str_equal,
+                                             g_free, g_free);
 }
 
 static void
@@ -232,6 +236,11 @@ dispose (GObject *object)
         priv->timer = NULL;
     }
 
+    if (priv->attributes) {
+        g_hash_table_unref(priv->attributes);
+        priv->attributes = NULL;
+    }
+
     G_OBJECT_CLASS(cut_test_parent_class)->dispose(object);
 }
 
@@ -326,8 +335,16 @@ cut_test_run (CutTest *test, CutTestContext *test_context, CutRunner *runner)
     }
     g_timer_stop(priv->timer);
 
-    if (success)
-        g_signal_emit_by_name(test, "success");
+    if (success) {
+        CutTestResult *result;
+        result = cut_test_result_new(CUT_TEST_RESULT_SUCCESS,
+                                     test,
+                                     NULL, NULL,
+                                     NULL, NULL, 
+                                     NULL, NULL, 0);
+        g_signal_emit_by_name(test, "success", result);
+        g_object_unref(result);
+    }
 
     g_signal_emit_by_name(test, "complete");
 
@@ -370,6 +387,37 @@ cut_test_get_elapsed (CutTest *test)
     return CUT_TEST_GET_CLASS(test)->get_elapsed(test);
 }
 
+const gchar *
+cut_test_get_attribute (CutTest *test, const gchar *name)
+{
+    return g_hash_table_lookup(CUT_TEST_GET_PRIVATE(test)->attributes, name);
+}
+
+void
+cut_test_set_attribute (CutTest *test, const gchar *name, const gchar *value)
+{
+    g_hash_table_replace(CUT_TEST_GET_PRIVATE(test)->attributes,
+                         g_strdup(name),
+                         g_strdup(value));
+}
+
+const GHashTable *
+cut_test_get_attributes (CutTest *test)
+{
+    return CUT_TEST_GET_PRIVATE(test)->attributes;
+}
+
+void
+cut_test_stop_timer (CutTest *test)
+{
+    CutTestPrivate *priv;
+
+    priv = CUT_TEST_GET_PRIVATE(test);
+
+    if (priv->timer)
+        g_timer_stop(priv->timer);
+}
+
 /*
 vi:ts=4:nowrap:ai:expandtab:sw=4
 */
