@@ -1,4 +1,4 @@
-/* -*- Mode: C; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
+/* -*- Mode: C; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*
  *  Copyright (C) 2007  Kouhei Sutou <kou@cozmixng.org>
  *
@@ -27,7 +27,6 @@
 #include <cutter/cut-private.h>
 #include <cutter/cut-assertions.h>
 #include <cutter/cut-test-context.h>
-#include <cutter/cut-test-result.h>
 
 G_BEGIN_DECLS
 
@@ -40,6 +39,9 @@ G_BEGIN_DECLS
 
 typedef struct _CutTestClass    CutTestClass;
 
+typedef struct _CutTestResult         CutTestResult;
+typedef struct _CutTestResultClass    CutTestResultClass;
+
 typedef void    (*CutTestFunction)     (void);
 typedef void    (*CutSetupFunction)    (void);
 typedef void    (*CutTearDownFunction) (void);
@@ -58,7 +60,8 @@ struct _CutTestClass
     void (*start)          (CutTest        *test);
     void (*pass_assertion) (CutTest        *test,
                             CutTestContext *context);
-    void (*success)        (CutTest        *test);
+    void (*success)        (CutTest        *test,
+                            CutTestResult  *result);
     void (*failure)        (CutTest        *test,
                             CutTestContext *context,
                             CutTestResult  *result);
@@ -87,12 +90,20 @@ CutTest     *cut_test_new                 (const gchar *function_name,
 gboolean     cut_test_run                 (CutTest        *test,
                                            CutTestContext *test_context,
                                            CutRunner      *runner);
+void         cut_test_stop_timer          (CutTest *test);        
 
 const gchar *cut_test_get_name            (CutTest *test);
 const gchar *cut_test_get_description     (CutTest *test);
 
 gdouble      cut_test_get_elapsed         (CutTest *test);
 
+const gchar *cut_test_get_attribute       (CutTest    *test,
+                                          const gchar *name);
+void         cut_test_set_attribute       (CutTest    *test,
+                                          const gchar *name,
+                                          const gchar *value);
+const GHashTable *cut_test_get_attributes (CutTest    *test);
+
 G_END_DECLS
 
 #endif /* __CUT_TEST_H__ */
