@@ -1,4 +1,4 @@
-/* -*- Mode: C; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
+/* -*- Mode: C; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*
  *  Copyright (C) 2007  Kouhei Sutou <kou@cozmixng.org>
  *
@@ -229,9 +229,17 @@ get_property (GObject    *object,
 static gboolean
 guess_color_usability (void)
 {
-    const gchar *term;
+    const gchar *term, *emacs;
+
     term = g_getenv("TERM");
-    return term && g_str_has_suffix(term, "term");
+    if (term && (g_str_has_suffix(term, "term") || g_str_equal(term, "screen")))
+        return TRUE;
+
+    emacs = g_getenv("EMACS");
+    if (emacs && (g_str_equal(emacs, "t")))
+        return TRUE;
+
+    return FALSE;
 }
 
 static gboolean
@@ -332,5 +340,5 @@ create (CutUIFactory *factory)
 }
 
 /*
-vi:ts=4:nowrap:ai:expandtab:sw=4
+vi:nowrap:ai:expandtab:sw=4
 */
