@@ -1,4 +1,4 @@
-/* -*- Mode: C; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
+/* -*- Mode: C; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*
  *  Copyright (C) 2007  Kouhei Sutou <kou@cozmixng.org>
  *
@@ -51,7 +51,7 @@
 #define GREEN_BACK_COLOR "\033[01;42m"
 #define YELLOW_COLOR "\033[01;33m"
 #define BLUE_COLOR "\033[01;34m"
-#define PURPLE_COLOR "\033[01;35m"
+#define MAGENTA_COLOR "\033[01;35m"
 #define CYAN_COLOR "\033[01;36m"
 #define WHITE_COLOR "\033[01;37m"
 #define NORMAL_COLOR "\033[00m"
@@ -280,10 +280,10 @@ status_to_color(CutTestResultStatus status)
         color = RED_COLOR;
         break;
       case CUT_TEST_RESULT_ERROR:
-        color = PURPLE_COLOR;
+        color = YELLOW_COLOR;
         break;
       case CUT_TEST_RESULT_PENDING:
-        color = YELLOW_COLOR;
+        color = MAGENTA_COLOR;
         break;
       case CUT_TEST_RESULT_NOTIFICATION:
         color = CYAN_COLOR;
@@ -390,11 +390,11 @@ cb_success (CutRunner *runner, CutTest *test, CutUIConsole *console)
 }
 
 static void
-cb_failure (CutRunner       *runner,
-            CutTest          *test,
-            CutTestContext   *test_context,
-            CutTestResult    *result,
-            CutUIConsole *console)
+cb_failure (CutRunner      *runner,
+            CutTest        *test,
+            CutTestContext *test_context,
+            CutTestResult  *result,
+            CutUIConsole   *console)
 {
     if (console->verbose_level < CUT_VERBOSE_LEVEL_NORMAL)
         return;
@@ -403,11 +403,11 @@ cb_failure (CutRunner       *runner,
 }
 
 static void
-cb_error (CutRunner       *runner,
-          CutTest          *test,
-          CutTestContext   *test_context,
-          CutTestResult    *result,
-          CutUIConsole *console)
+cb_error (CutRunner      *runner,
+          CutTest        *test,
+          CutTestContext *test_context,
+          CutTestResult  *result,
+          CutUIConsole   *console)
 {
     if (console->verbose_level < CUT_VERBOSE_LEVEL_NORMAL)
         return;
@@ -416,11 +416,11 @@ cb_error (CutRunner       *runner,
 }
 
 static void
-cb_pending (CutRunner       *runner,
-            CutTest          *test,
-            CutTestContext   *test_context,
-            CutTestResult    *result,
-            CutUIConsole *console)
+cb_pending (CutRunner      *runner,
+            CutTest        *test,
+            CutTestContext *test_context,
+            CutTestResult  *result,
+            CutUIConsole   *console)
 {
     if (console->verbose_level < CUT_VERBOSE_LEVEL_NORMAL)
         return;
@@ -429,11 +429,11 @@ cb_pending (CutRunner       *runner,
 }
 
 static void
-cb_notification (CutRunner       *runner,
-                 CutTest          *test,
-                 CutTestContext   *test_context,
-                 CutTestResult    *result,
-                 CutUIConsole *console)
+cb_notification (CutRunner      *runner,
+                 CutTest        *test,
+                 CutTestContext *test_context,
+                 CutTestResult  *result,
+                 CutUIConsole   *console)
 {
     if (console->verbose_level < CUT_VERBOSE_LEVEL_NORMAL)
         return;
@@ -460,6 +460,33 @@ cb_complete_test_case (CutRunner *runner, CutTestCase *test_case,
         return;
 }
 
+typedef struct _ConsoleAndStatus {
+    CutUIConsole *console;
+    CutTestResultStatus status;
+} ConsoleAndStatus;
+
+static void
+print_each_attribute (gpointer key, gpointer value, gpointer data)
+{
+    ConsoleAndStatus *info = (ConsoleAndStatus*)data;
+    g_print("\n");
+    print_with_color(info->console, status_to_color(info->status),
+                     "  %s: %s",
+                     (const gchar*)key, (const gchar*)value,
+                     NULL);
+}
+
+static void
+print_test_attributes (CutUIConsole *console, CutTestResultStatus status,
+                     CutTest *test)
+{
+    ConsoleAndStatus info;
+    info.console = console;
+    info.status = status;
+    g_hash_table_foreach((GHashTable*)cut_test_get_attributes(test),
+                         (GHFunc)print_each_attribute, &info);
+}
+
 static void
 print_results (CutUIConsole *console, CutRunner *runner)
 {
@@ -475,11 +502,16 @@ print_results (CutUIConsole *console, CutRunner *runner)
          node = g_list_next(node)) {
         CutTestResult *result = node->data;
         CutTestResultStatus status;
+        CutTest *test;
         gchar *filename;
         const gchar *message;
         const gchar *source_directory;
         const gchar *name;
 
+        status = cut_test_result_get_status(result);
+        if (status == CUT_TEST_RESULT_SUCCESS)
+            continue; 
+
         source_directory = cut_runner_get_source_directory(runner);
         if (source_directory)
             filename = g_build_filename(source_directory,
@@ -488,7 +520,6 @@ print_results (CutUIConsole *console, CutRunner *runner)
         else
             filename = g_strdup(cut_test_result_get_filename(result));
 
-        status = cut_test_result_get_status(result);
         message = cut_test_result_get_message(result);
         name = cut_test_result_get_test_name(result);
         if (!name)
@@ -500,6 +531,10 @@ print_results (CutUIConsole *console, CutRunner *runner)
         print_for_status(console, status, "%s: %s",
                          status_to_name(status), name);
 
+        test = cut_test_result_get_test(result);
+        if (test) 
+            print_test_attributes(console, status, test);
+
         if (message) {
             g_print("\n");
             print_for_status(console, status, "%s", message);
