@@ -46,5 +46,5 @@ text_invalid_prefix_function (void)
 }
 
 /*
-vi:ts=4:nowrap:ai:expandtab:sw=4
+vi:nowrap:ai:expandtab:sw=4
 */
