@@ -3,6 +3,7 @@
 #include "cut-test-result.h"
 #include "cut-utils.h"
 #include "cut-runner.h"
+#include "cuttest-assertions.h"
 
 void test_equal_int(void);
 void test_equal_string(void);
@@ -11,6 +12,7 @@ void test_operator(void);
 void test_equal_string_array (void);
 void test_null(void);
 void test_null_string(void);
+void test_equal_string_with_free(void);
 void test_error(void);
 void test_fail(void);
 void test_pending(void);
@@ -55,15 +57,15 @@ dummy_fail_test_function (void)
 }
 
 static void
-dummy_pending_test_function (void)
+dummy_pend_test_function (void)
 {
-    cut_pending("This test has been pending ever!");
+    cut_pend("This test has been pending ever!");
 }
 
 static void
 dummy_notify_test_function (void)
 {
-    cut_notify("This test has been notify ever!");
+    cut_notify("This test has been notifying ever!");
 }
 
 static void
@@ -209,44 +211,6 @@ test_error_equal_string (void)
     cut_assert(!run(test));
 }
 
-static void
-cut_assert_test_result_summary (gint n_tests, gint n_assertions,
-                                gint n_failures, gint n_errors,
-                                gint n_pendings, gint n_notifications)
-{
-    cut_assert_equal_int(n_tests, cut_runner_get_n_tests(runner));
-    cut_assert_equal_int(n_assertions, cut_runner_get_n_assertions(runner));
-    cut_assert_equal_int(n_failures, cut_runner_get_n_failures(runner));
-    cut_assert_equal_int(n_errors, cut_runner_get_n_errors(runner));
-    cut_assert_equal_int(n_pendings, cut_runner_get_n_pendings(runner));
-    cut_assert_equal_int(n_notifications,
-                         cut_runner_get_n_notifications(runner));
-}
-
-static void
-cut_assert_test_result (gint i, CutTestResultStatus status,
-                        const gchar *test_name,
-                        const gchar *user_message, const gchar *system_message,
-                        const gchar *function_name)
-{
-    const GList *results;
-    CutTestResult *result;
-
-    results = cut_runner_get_results(runner);
-    cut_assert_operator_int(i, <, g_list_length((GList *)results));
-
-    result = g_list_nth_data((GList *)results, i);
-    cut_assert(result);
-    cut_assert_equal_int(status, cut_test_result_get_status(result));
-    cut_assert_equal_string(test_name, cut_test_result_get_test_name(result));
-    cut_assert_equal_string_or_null(user_message,
-                                    cut_test_result_get_user_message(result));
-    cut_assert_equal_string_or_null(system_message,
-                                    cut_test_result_get_system_message(result));
-    cut_assert_equal_string(function_name,
-                            cut_test_result_get_function_name(result));
-}
-
 void
 test_error (void)
 {
@@ -256,8 +220,8 @@ test_error (void)
     cut_assert(test, "Creating a new CutTest object failed");
 
     cut_assert(!run(test));
-    cut_assert_test_result_summary(1, 0, 0, 1, 0, 0);
-    cut_assert_test_result(0, CUT_TEST_RESULT_ERROR, "dummy-error-test",
+    cut_assert_test_result_summary(runner, 1, 0, 0, 1, 0, 0);
+    cut_assert_test_result(runner, 0, CUT_TEST_RESULT_ERROR, "dummy-error-test",
                            "This test should error", NULL,
                            "dummy_error_test_function");
 }
@@ -267,12 +231,12 @@ test_pending (void)
 {
     CutTest *test;
 
-    test = cut_test_new("dummy-pending-test", NULL, dummy_pending_test_function);
+    test = cut_test_new("dummy-pend-test", NULL, dummy_pend_test_function);
     cut_assert(test, "Creating a new CutTest object failed");
 
     g_signal_connect(test, "pending", G_CALLBACK(cb_collect_result),
                      &test_result);
-    cut_assert(!run(test), "cut_pending() did not return FALSE!");
+    cut_assert(!run(test), "cut_pend() did not return FALSE!");
     g_signal_handlers_disconnect_by_func(test,
                                          G_CALLBACK(cb_collect_result),
                                          &test_result);
@@ -444,11 +408,30 @@ test_null_string (void)
 
     test = cut_test_new("assert-null-string", NULL, null_string_assertions);
     cut_assert(!run(test));
-    cut_assert_test_result_summary(1, 1, 1, 0, 0, 0);
+    cut_assert_test_result_summary(runner, 1, 1, 1, 0, 0, 0);
 }
 
+static void
+equal_string_with_free_assertions ()
+{
+    cut_assert_equal_string_with_free(NULL, NULL);
+    cut_assert_equal_string_with_free("", g_strdup(""));
+    cut_assert_equal_string_with_free("xxx", g_strdup("xxx"));
+    cut_assert_equal_string_with_free("xxx", g_strdup("zzz"));
+}
+
+void
+test_equal_string_with_free (void)
+{
+    CutTest *test;
+
+    test = cut_test_new("assert-string-equal-string-with-free",
+                        NULL, equal_string_with_free_assertions);
+    cut_assert(!run(test));
+    cut_assert_test_result_summary(runner, 1, 3, 1, 0, 0, 0);
+}
 
 /*
-vi:ts=4:nowrap:ai:expandtab:sw=4
+vi:nowrap:ai:expandtab:sw=4
 */
 
